==> react-bootstrap-formkit-1.0.5.tgz: package/README.md <==
## Hello Everyone...
react-bootstrap-formkit is a pakage for react form creating and handling. In this package I have used Bootstrap for making grid form and styling. This is new project and 3 types of form fields text, radio and checkbox are supporting until now.

## Installation:
```
import  FormKit from "react-bootstrap-formkit";
``` 

### Now use it in your component:

```
function App() {

  const handleSubmit = async data => {
    console.log("on submit called");
    console.log(data); 
  };

  return (
    <div className="App">
      <div className="container">
        <FormKit 
            fields={}
            submitButton = {}
            onSubmit = {}
            initialValue = {}
        />
      </div>
    </div>
  );
}
```

## Props:

1. fields: This is an array which contains grid information. this package works with bootstrap grid. Sample object: 
```
let formGrid = 
[
    [
      {type: "text", label: "First Name", key: "1", id: "firstname", name: "firstname", required: true},
      {type: "text", label: "Last Name", key: "2", id: "lastname", name: "lastname"},
      {type: "text", label: "City", key: "3", id: "city", name: "city"},

    ],
    [
      {type: "text", label: "Age", key: "4", id: "age", name: "age"},
      {type: "text", label: "Address", key: "5", id: "address", name: "address"}
    ],
    [
      {type: "radio", label: "Male", key: "6", id: "gender", name: "gender", value: "male"},
      {type: "radio", label: "Female", key: "7", id: "gender", name: "gender", value: "female"}
    ],
    [
      {type: "checkbox", label: "Doctor", key: "8", id: "profession", name: "profession", value: "doctor"},
      {type: "checkbox", label: "Engineer", key: "9", id: "profession", name: "profession", value: "engineer"}
    ]
]
```

2. submitButton: This is an object contain information of submit button.
```
let submitBtnInfo = 
    {
        name: "Save",
        className: "btn btn-outline-primary btn-md float-right"
    }
```
3. onSubmit : This is a handler method which take data and you can use those data for further processing.

```
const handleSubmit = async data => {
    console.log("On Submit Called");
    console.log(data);
  };
```
4. initialValue : Initial State for the form fields. This is an object and key/value pair of form field name and value. This will helpful for form auto fill-up. 

```
let initialState = 
{
    firstname : "Shohidul",
    lastname : "Bari",
    city : "Dhaka"
    age : null, 
    address: null,
    gender: "male",
    profession: ["engineer"]
}
```
Look... I have only given support for text, radio and checkbox only untill now. initial datatype for those are,
text : String
radio : String
checkbox : List

## Note 
Please Make sure that you have configured bootstrap 4 with CDN or importing from any other source to your project.

==> react-bootstrap-formkit-1.0.7.tgz: package/README.md <==
## Hello Everyone...
react-bootstrap-formkit is a pakage for react form creating and handling. In this package I have used Bootstrap for making grid form and styling. This is new package and 3 types of form fields are supporting until now.

## Supported Form Fields
1. Text : Initial value should be in text/string.
2. Radio : Initial value should be in text/string.
3. Checkbox : Initial value should be an array and same format array will be returned when form submitted.

## Installation:
```
npm i react-bootstrap-formkit
``` 

### Now use it in your component:

```
import  FormKit from "react-bootstrap-formkit";

function App() {
  return (
    <div className="App">
      <div className="container">
        <FormKit 
            fields={}
            submitButton = {}
            onSubmit = {}
            initialValue = {}
        />
      </div>
    </div>
  );
}
```

## Props:

### All props are required.

### fields: 
This is an array which contains grid information. this package works with bootstrap grid. Sample object: 
```
let formGrid = 
[
    [
      {type: "text", label: "First Name", key: "1", id: "firstname", name: "firstname", required: true},
      {type: "text", label: "Last Name", key: "2", id: "lastname", name: "lastname"},
      {type: "text", label: "City", key: "3", id: "city", name: "city"},

    ],
    [
      {type: "text", label: "Age", key: "4", id: "age", name: "age"},
      {type: "text", label: "Address", key: "5", id: "address", name: "address"}
    ],
    [
      {type: "radio", label: "Male", key: "6", id: "gender", name: "gender", value: "male"},
      {type: "radio", label: "Female", key: "7", id: "gender", name: "gender", value: "female"}
    ],
    [
      {type: "checkbox", label: "Doctor", key: "8", id: "profession", name: "profession", value: "doctor"},
      {type: "checkbox", label: "Engineer", key: "9", id: "profession", name: "profession", value: "engineer"}
    ]
]
```

### submitButton: 
This is an object contain information of submit button.
```
let submitBtnInfo = 
    {
        name: "Save",
        className: "btn btn-outline-primary btn-md float-right"
    }
```
### onSubmit: 
This is a handler method which take data and you can use those data for further processing.

```
const handleSubmit = async data => {
    console.log("On Submit Called");
    console.log(data);
  };
```
### initialValue: 
Initial State for the form fields. This is an object and key/value pair of form field name and value. This will helpful for form auto fill-up. 

```
let initialState = 
{
    firstname : "Shohidul",
    lastname : "Bari",
    city : "Dhaka"
    age : null, 
    address: null,
    gender: "male",
    profession: ["engineer"]
}
```
Look... I have only given support for text, radio and checkbox only untill now. initial datatype for those are,
text : String
radio : String
checkbox : List

## Note 
Please Make sure that you have configured bootstrap 4 with CDN or importing from any other source to your project.
